@@ -179,6 +179,10 @@ void parseirc(char *serveroutput)
 		if((this = getchptr(channel)) == NULL) {
 			return;
 		}
+                if(haschanflags(channel, "T")) {
+                        /* skip topic handling for this channel */
+                        return;
+                }
 		if(this->topics != NULL) {
 			/* only parse topic if oer has none for this channel.
 			   this is a kludge to avoid empty topics in undernet */
@@ -888,6 +892,13 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 	switch((which = whichcommand(command, wordcount(restptr)))) {
 	case OER_WHICHCOMMAND_TOPIC_SET:
 		oer_debug(OER_DEBUG_INFO, "parsecommand->TOPIC_SET\n");
+                if(haschanflags(channel, "T")) {
+                        /* skip topic handling for this channel */
+                        return;
+                }
+                if(haschanflags(channel, "U") && !isatleastop(channel, nick, host)) {
+                        return;
+                }
 		if(!isatleastopnow(channel, nick, host)) {
 			return;
 		}
@@ -901,6 +912,13 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		return;
 	case OER_WHICHCOMMAND_TOPIC_ADD:
 		oer_debug(OER_DEBUG_INFO, "parsecommand->TOPIC_ADD\n");
+                if(haschanflags(channel, "T")) {
+                        /* skip topic handling for this channel */
+                        return;
+                }
+                if(haschanflags(channel, "U") && !isatleastop(channel, nick, host)) {
+                        return;
+                }
 		if(!isatleastopnow(channel, nick, host)) {
 			return;
 		}
@@ -913,6 +931,13 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		return;
 	case OER_WHICHCOMMAND_TOPIC_DEL:
 		oer_debug(OER_DEBUG_INFO, "parsecommand->TOPIC_DEL\n");
+                if(haschanflags(channel, "T")) {
+                        /* skip topic handling for this channel */
+                        return;
+                }
+                if(haschanflags(channel, "U") && !isatleastop(channel, nick, host)) {
+                        return;
+                }
                 if(!isatleastopnow(channel, nick, host)) {
                         return;
                 }
@@ -928,6 +953,13 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		return;
 	case OER_WHICHCOMMAND_TOPIC_EDIT:
 		oer_debug(OER_DEBUG_INFO, "parsecommand->TOPIC_EDIT\n");
+                if(haschanflags(channel, "T")) {
+                        /* skip topic handling for this channel */
+                        return;
+                }
+                if(haschanflags(channel, "U") && !isatleastop(channel, nick, host)) {
+                        return;
+                }
                 if(!isatleastopnow(channel, nick, host)) {
                         return;
                 }
@@ -944,6 +976,13 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		return;
 	case OER_WHICHCOMMAND_TOPIC_INS:
 		oer_debug(OER_DEBUG_INFO, "parsecommand->TOPIC_INS\n");
+                if(haschanflags(channel, "T")) {
+                        /* skip topic handling for this channel */
+                        return;
+                }
+                if(haschanflags(channel, "U") && !isatleastop(channel, nick, host)) {
+                        return;
+                }
                 if(!isatleastopnow(channel, nick, host)) {
                         return;
                 }
@@ -960,6 +999,13 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		return;
 	case OER_WHICHCOMMAND_TOPIC_LIST:
 		oer_debug(OER_DEBUG_INFO, "parsecommand->TOPIC_LIST\n");
+                if(haschanflags(channel, "T")) {
+                        /* skip topic handling for this channel */
+                        return;
+                }
+                if(haschanflags(channel, "U") && !isatleastop(channel, nick, host)) {
+                        return;
+                }
                 if(!isatleastopnow(channel, nick, host)) {
                         return;
                 }
@@ -967,6 +1013,13 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		return;
 	case OER_WHICHCOMMAND_TOPIC_GET:
 		oer_debug(OER_DEBUG_INFO, "parsecommand->TOPIC_GET\n");
+                if(haschanflags(channel, "T")) {
+                        /* skip topic handling for this channel */
+                        return;
+                }
+                if(haschanflags(channel, "U") && !isatleastop(channel, nick, host)) {
+                        return;
+                }
                 if(!isatleastopnow(channel, nick, host)) {
                         return;
                 }
@@ -976,6 +1029,13 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		return;
 	case OER_WHICHCOMMAND_TOPIC_REFRESH:
 		oer_debug(OER_DEBUG_INFO, "parsecommand->TOPIC_REFRESH\n");
+                if(haschanflags(channel, "T")) {
+                        /* skip topic handling for this channel */
+                        return;
+                }
+                if(haschanflags(channel, "U") && !isatleastop(channel, nick, host)) {
+                        return;
+                }
                 if(!isatleastopnow(channel, nick, host)) {
                         return;
                 }
@@ -985,6 +1045,13 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		return;
 	case OER_WHICHCOMMAND_TOPIC_SWAP:
 		oer_debug(OER_DEBUG_INFO, "parsecommand->TOPIC_SWAP\n");
+                if(haschanflags(channel, "T")) {
+                        /* skip topic handling for this channel */
+                        return;
+                }
+                if(haschanflags(channel, "U") && !isatleastop(channel, nick, host)) {
+                        return;
+                }
                 if(!isatleastopnow(channel, nick, host)) {
                         return;
                 }
@@ -1022,6 +1089,9 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		return;
 	case OER_WHICHCOMMAND_UNLOCK:
 		oer_debug(OER_DEBUG_INFO, "parsecommand->UNLOCK\n");
+                if(haschanflags(channel, "U") && !isatleastop(channel, nick, host)) {
+                        return;
+                }
                 if(!isatleastopnow(channel, nick, host)) {
                         return;
                 }
@@ -1075,6 +1145,9 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		return;
 	case OER_WHICHCOMMAND_SYNC:
 		oer_debug(OER_DEBUG_INFO, "parsecommand->SYNC\n");
+                if(haschanflags(channel, "U") && !isatleastop(channel, nick, host)) {
+                        return;
+                }
                 if(!isatleastopnow(channel, nick, host)) {
                         return;
                 }
@@ -1128,6 +1201,9 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		return;
 	case OER_WHICHCOMMAND_OP:
 		oer_debug(OER_DEBUG_INFO, "parsecommand->OP\n");
+                if(haschanflags(channel, "U") && !isatleastop(channel, nick, host)) {
+                        return;
+                }
                 if(!isatleastopnow(channel, nick, host)) {
                         return;
                 }
@@ -1159,6 +1235,9 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		return;
 	case OER_WHICHCOMMAND_DOP:
 		oer_debug(OER_DEBUG_INFO, "parsecommand->DOP\n");
+                if(haschanflags(channel, "U") && !isatleastop(channel, nick, host)) {
+                        return;
+                }
                 if(!isatleastopnow(channel, nick, host)) {
                         return;
                 }
@@ -1187,6 +1266,9 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		return;
 	case OER_WHICHCOMMAND_VOICE:
 		oer_debug(OER_DEBUG_INFO, "parsecommand->VOICE\n");
+                if(haschanflags(channel, "U") && !isatleastop(channel, nick, host)) {
+                        return;
+                }
                 if(!isatleastopnow(channel, nick, host)) {
                         return;
                 }
@@ -1215,6 +1297,9 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		return;
 	case OER_WHICHCOMMAND_BAN:
 		oer_debug(OER_DEBUG_INFO, "parsecommand->BAN\n");
+                if(haschanflags(channel, "U") && !isatleastop(channel, nick, host)) {
+                        return;
+                }
                 if(!isatleastopnow(channel, nick, host)) {
                         return;
                 }
@@ -1237,6 +1322,9 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		return;
 	case OER_WHICHCOMMAND_UNBAN:
 		oer_debug(OER_DEBUG_INFO, "parsecommand->UNBAN\n");
+                if(haschanflags(channel, "U") && !isatleastop(channel, nick, host)) {
+                        return;
+                }
                 if(!isatleastopnow(channel, nick, host)) {
                         return;
                 }
@@ -1259,6 +1347,9 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		return;
 	case OER_WHICHCOMMAND_BANKICK:
 		oer_debug(OER_DEBUG_INFO, "parsecommand->BANKICK\n");
+                if(haschanflags(channel, "U") && !isatleastop(channel, nick, host)) {
+                        return;
+                }
                 if(!isatleastopnow(channel, nick, host)) {
                         return;
                 }
@@ -1277,6 +1368,9 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		return;
 	case OER_WHICHCOMMAND_KICK:
 		oer_debug(OER_DEBUG_INFO, "parsecommand->KICK\n");
+                if(haschanflags(channel, "U") && !isatleastop(channel, nick, host)) {
+                        return;
+                }
                 if(!isatleastopnow(channel, nick, host)) {
                         return;
                 }
@@ -1294,6 +1388,9 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		return;
 	case OER_WHICHCOMMAND_INVITE:
 		oer_debug(OER_DEBUG_INFO, "parsecommand->INVITE\n");
+                if(haschanflags(channel, "U") && !isatleastop(channel, nick, host)) {
+                        return;
+                }
                 if(!isatleastopnow(channel, nick, host)) {
                         return;
                 }
@@ -1318,6 +1415,9 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		return;
 	case OER_WHICHCOMMAND_MODE:
 		oer_debug(OER_DEBUG_INFO, "parsecommand->MODE\n");
+                if(haschanflags(channel, "U") && !isatleastop(channel, nick, host)) {
+                        return;
+                }
                 if(!isatleastopnow(channel, nick, host)) {
                         return;
                 }
@@ -1354,6 +1454,9 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		oer_debug(OER_DEBUG_INFO, "parsecommand->HELP\n");
 		proceed = 0;
 		for(this = mystate->channels; this != NULL && !proceed; this = this->next) {
+			if(haschanflags(this->name, "U") && !isatleastop(this->name, nick, host)) {
+				continue;
+			}
 			if(isatleastopnow(this->name, nick, host)) {
 				proceed = 1;
 			}
@@ -1371,6 +1474,9 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		   are checked in listcommand() */
 		proceed = 0;
 		for(this = mystate->channels; this != NULL && !proceed; this = this->next) {
+			if(haschanflags(this->name, "U") && !isatleastop(this->name, nick, host)) {
+				continue;
+			}
 			if(isatleastopnow(this->name, nick, host)) {
 				proceed = 1;
 			}
@@ -1414,6 +1520,9 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		return;
 	case OER_WHICHCOMMAND_ADD:
 		oer_debug(OER_DEBUG_INFO, "parsecommand->ADD\n");
+		if(haschanflags(channel, "U") && !isatleastop(channel, nick, host)) {
+			return;
+		}
                 if(!isatleastopnow(channel, nick, host)) {
                         return;
                 }
@@ -1423,6 +1532,9 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		return;
 	case OER_WHICHCOMMAND_DEL:
 		oer_debug(OER_DEBUG_INFO, "parsecommand->DEL\n");
+		if(haschanflags(channel, "U") && !isatleastop(channel, nick, host)) {
+			return;
+		}
                 if(!isatleastopnow(channel, nick, host)) {
                         return;
                 }
@@ -1432,6 +1544,9 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		return;
 	case OER_WHICHCOMMAND_EDIT:
 		oer_debug(OER_DEBUG_INFO, "parsecommand->EDIT\n");
+		if(haschanflags(channel, "U") && !isatleastop(channel, nick, host)) {
+			return;
+		}
                 if(!isatleastopnow(channel, nick, host)) {
                         return;
                 }
@@ -1443,6 +1558,9 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		oer_debug(OER_DEBUG_INFO, "parsecommand->SAVE\n");
 		proceed = 0;
 		for(this = mystate->channels; this != NULL && !proceed; this = this->next) {
+			if(haschanflags(this->name, "U") && !isatleastop(this->name, nick, host)) {
+				continue;
+			}
 			if(isatleastopnow(this->name, nick, host)) {
 				proceed = 1;
 			}
@@ -1457,6 +1575,9 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		oer_debug(OER_DEBUG_INFO, "parsecommand->FLUSH\n");
 		proceed = 0;
 		for(this = mystate->channels; this != NULL && !proceed; this = this->next) {
+			if(haschanflags(this->name, "U") && !isatleastop(this->name, nick, host)) {
+				continue;
+			}
 			if(isatleastopnow(this->name, nick, host)) {
 				proceed = 1;
 			}
@@ -1470,6 +1591,9 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		oer_debug(OER_DEBUG_INFO, "parsecommand->INFO\n");
 		proceed = 0;
 		for(this = mystate->channels; this != NULL && !proceed; this = this->next) {
+			if(haschanflags(this->name, "U") && !isatleastop(this->name, nick, host)) {
+				continue;
+			}
 			if(isatleastopnow(this->name, nick, host)) {
 				proceed = 1;
 			}
@@ -1484,6 +1608,9 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		oer_debug(OER_DEBUG_INFO, "parsecommand->UPTIME\n");
 		proceed = 0;
 		for(this = mystate->channels; this != NULL && !proceed; this = this->next) {
+			if(haschanflags(this->name, "U") && !isatleastop(this->name, nick, host)) {
+				continue;
+			}
 			if(isatleastopnow(this->name, nick, host)) {
 				proceed = 1;
 			}
@@ -1506,6 +1633,9 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		return;
 	case OER_WHICHCOMMAND_ACTION:
 		oer_debug(OER_DEBUG_INFO, "parsecommand->ACTION\n");
+		if(haschanflags(channel, "U") && !isatleastop(channel, nick, host)) {
+			return;
+		}
                 if(!isatleastopnow(channel, nick, host)) {
                         return;
                 }
@@ -1516,6 +1646,9 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		return;
 	case OER_WHICHCOMMAND_SAY:
 		oer_debug(OER_DEBUG_INFO, "parsecommand->SAY\n");
+		if(haschanflags(channel, "U") && !isatleastop(channel, nick, host)) {
+			return;
+		}
                 if(!isatleastopnow(channel, nick, host)) {
                         return;
                 }
@@ -1535,6 +1668,9 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		return;
 	case OER_WHICHCOMMAND_LAST:
 		oer_debug(OER_DEBUG_INFO, "parsecommand->LAST\n");
+		if(haschanflags(channel, "U") && !isatleastop(channel, nick, host)) {
+			return;
+		}
                 if(!isatleastopnow(channel, nick, host)) {
                         return;
                 }
@@ -1542,6 +1678,9 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		return;
 	case OER_WHICHCOMMAND_QUOTE:
 		oer_debug(OER_DEBUG_INFO, "parsecommand->QUOTE\n");
+		if(haschanflags(channel, "U") && !isatleastop(channel, nick, host)) {
+			return;
+		}
                 if(!isatleastopnow(channel, nick, host)) {
                         return;
                 }
@@ -1559,6 +1698,9 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		return;
 	case OER_WHICHCOMMAND_SEEN:
 		oer_debug(OER_DEBUG_INFO, "parsecommand->SEEN\n");
+		if(haschanflags(channel, "U") && !isatleastop(channel, nick, host)) {
+			return;
+		}
                 if(!isatleastopnow(channel, nick, host)) {
                         return;
                 }
@@ -1566,6 +1708,9 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		return;
 	case OER_WHICHCOMMAND_NSTATS:
 		oer_debug(OER_DEBUG_INFO, "parsecommand->NSTATS\n");
+		if(haschanflags(channel, "U") && !isatleastop(channel, nick, host)) {
+			return;
+		}
                 if(!isatleastopnow(channel, nick, host)) {
                         return;
                 }
@@ -1576,6 +1721,9 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		return;
 	case OER_WHICHCOMMAND_WALL:
 		oer_debug(OER_DEBUG_INFO, "parsecommand->WALL\n");
+		if(haschanflags(channel, "U") && !isatleastop(channel, nick, host)) {
+			return;
+		}
                 if(!isatleastopnow(channel, nick, host)) {
                         return;
                 }
